#
# spec file for package python-osc-tiny
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15allpythons}
Name:           python-osc-tiny
Version:        0.10.6
Release:        1.2
Summary:        Client API for openSUSE BuildService
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/SUSE/osc-tiny
Source:         https://files.pythonhosted.org/packages/source/o/osc-tiny/osc_tiny-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/SUSE/osc-tiny/pull/204 fix test failure in PY13
Patch:          py313.patch
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module urllib3}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-lxml
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-requests
Requires:       python-urllib3
Suggests:       openssh
BuildArch:      noarch
# Using 'if' instead of 'with' because the latter requires rpm >= 4.14
%if 0%{?suse_version} >= 1550
BuildRequires:  %{python_module cached-property if %python-base < 3.8}
%else
BuildRequires:  %{python_module cached-property}
%endif
%python_subpackages

%description
OSC Tiny provides a minimalistic, transparent and class based client for
accessing the OpenBuildService API.

For further details see:

 * https://osc-tiny.readthedocs.io/en/latest/
 * https://openbuildservice.org/
 * https://build.opensuse.org/apidocs/index

%prep
%autosetup -p1 -n osc_tiny-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/osctiny
%{python_sitelib}/osc_tiny-%{version}*-info

%changelog
* Tue Dec 10 2024 Markéta Machová <mmachova@suse.com>
- Add patch py313.patch to fix test failure
* Tue Nov 26 2024 maintenance-obs-robot <maintenance-automation-team@suse.de>
- Release 0.10.6
  * Fix: in changelog packager must contain email address
  * Docs: Updates
  * move contact email to action variables
* Tue Oct 29 2024 maintenance-obs-robot <maintenance-automation-team@suse.de>
- Release 0.10.5
  * Fix: request review - always default to state="new", because OBS considers it a mandatory attribute (fixes #194)
  * Docs: fix logger name in `quickstart.rst`
* Wed Sep 25 2024 maintenance-obs-robot <maintenance-automation-team@suse.de>
- Release 0.10.4
  * osctiny.models.request.Target model: add an optional 'repository' attribute (fixes #183) (#184)
  * osctiny.models.request.Target model: make the 'package' attribute optional (fixes #185) (#186)
  * Chore: Updated versions of GH actions (#189)
* Tue Aug 13 2024 Matej Cepl <mcepl@cepl.eu>
- Release 0.10.3
  * Fixed default value for CA path
  * Removed support for .osc data directory
  * Handle issues due to bugs in backports of responses
  * Auto release OBS: using osc-tiny and improved change log
* Tue Aug 13 2024 Chen Huang <chhuang@suse.com>
- Release v0.10.2
  * Replaced get_cookie_jar function with a CookieManager (#171)
  * Use urllib3.Retry instead of custom implementation
  * Use the latest Python version for actions
  * Automate the release on OBS(closes #138) (#170)
* Fri Jun 28 2024 Chen Huang <chhuang@suse.com>
- Release 0.10.1
  * Include description in request creation
* Thu Jun 27 2024 Chen Huang <chhuang@suse.com>
- Release 0.10.0
  * Added capability to create requests (#165)
  * Install the theme for the docs (#163)
* Wed May 22 2024 Gabriel Niebler <gniebler@suse.com>
- Release 0.9.1
  * Staging extension: fix the return value of set_status_report() (fixes #158)
  * Document OBS release process
* Mon May 13 2024 Gabriel Niebler <gniebler@suse.com>
- Release 0.9.0
  * Staging extension (closes #151) (#154)
  * Type annotations and models
* Mon May 13 2024 Robert Frohl <rfrohl@suse.com>
- Use sle15allpythons to build for all SLE/Leap python versions
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.2:
  * If `osc` raises an exception, pretend it is not there
* Mon Dec 11 2023 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.8.1
  * Support for new OSC config
* Wed Nov 29 2023 Chen Huang <chhuang@suse.com>
- Release 0.8.0
  * Added the attributes extension
  * Project.get_meta: target the /_project path to really get specific revisions
  * Add an optional rev parameter to Project.get_meta
  * Reusable function to extract error message from responses and converted get_objectified_xml into standalone function
  * Removed backport of lru_cache
  * Session optimizations
  * Add Build.get_log
* Mon Mar  6 2023 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release .0.7.12
  * Enhanced usability and reliability for `HttpSignatureAuth`
  * Prevent sharing of sessions across forked processes
  * Fixed typo in quickstart doc
* Mon Jan  9 2023 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.11
  * Make it possible to force setting meta
  * Improved strong authentication method
  * Support product list views honoring the `expand` parameter
* Mon Jan  2 2023 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.10
  * Include the original error message, when an SSH key cannot be read
  * Added a link to the documentation of `HttpSignatureAuth`
  * Allow `Package.exists` to raise exceptions
  * Added methods to get/set the project config
* Mon Dec 12 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.9
  * Simplified handling of SSH keys (fixes #114)
  * Replaced `Request.cmd` with `Request.update` (fixes #113)
  * Added a comment parameter to project and package `set_meta`
* Wed Nov  2 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.7
  * Support for Python 3.11
  * Workaround for another parameter inconsistency in the API
* Thu Oct 20 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.6
  * Treat `deleted` and `expand` parameters of `/source/<project>/`
    as boolean (despite not being documented as such)
  * Do not send the `deleted` parameter, when the `view` parameter
    is present
* Fri Oct  7 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.5
  * Workaround for another inconsistency in parameter handling in OBS API
* Wed Oct  5 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.4
  * Deprecated `Project.get_files` (fixes #101)
    (i.e. yet another workaround for an inconsistent server API)
  * Updated documentation for `Package.cmd` method
* Mon Sep 19 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.3
  * Consider "boolean" parameters of specific API endpoints (fixes #97)
    Workaround for
    https://github.com/openSUSE/open-build-service/issues/9715
* Mon Sep 19 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.2
  * Suppress logging of response content when streaming
  * Fixed error in docstring
  * Removed Python2 support libararies (closes #81)
  * Removed warning about boolean query params
  * Fixed issues in `Project.put_meta` (fixes #84)
  * Deprecated `projects.put_meta` in favor of using `set_meta` (fixes #85)
* Tue Aug 16 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.1
  * Make distinction between "true" booleans and pretenders
* Tue Aug 16 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.7.0
  * Support setting of multiple values on attribute
  * Added feature to download binaries
  * Handle boolean query params
  * Convert relative paths to SSH keys to absolute paths
* Wed Aug  3 2022 Marina Latini <marina.latini@suse.com>
- Buildrequires cached-property always, not only for Python lower than 3.8
  * This is needed due to a mismatching python-rpm-macros
* Wed Aug  3 2022 Matej Cepl <mcepl@suse.com>
- Fix conditional Requires and BuildRequires.
* Tue Aug  2 2022 Matej Cepl <mcepl@suse.com>
- It's PyYAML, not pyYAML.
* Tue Aug  2 2022 Matej Cepl <mcepl@suse.com>
- Fix two typos
* Mon Aug  1 2022 Marina Latini <marina.latini@suse.com>
- Enhanced dependency management for Py3.7 and earlier
  * Re-add `responses` that is needed for building tests
- Use python_module macro for build requires
- Remove the BuildRequires:  %%{python_module devel}
- Refactoring of spec file with spec-cleaner
* Thu Jul 21 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.6
  * Workaround for credential mangers of `osc` having different return types
* Wed Jul 20 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.5: Enhanced dependency management
  * Removed `responses` as requirement
  * Use `cached_property` instead of `backports.cached_property`
    (which is not in the openSUSE repos)
  * Only install `cached_property` as requirement for Py3.7 and earlier
* Tue Jul 19 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.4
  * Handle 40x (x!=1) responses properly in `HttpSignatureAuth`
* Mon Jul 18 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.3
  * Do not assume that `oscrc` contains the SSH passphrase
  * Handle absence of `sshkey` in `.oscrc` gracefully
* Thu Jun 30 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.2
  * Added `cmd` method to `Build` extension
  * Fixes for sessions and authentication:
  * Use thread-safe sessions and support huge trees again
  * Support for server returning multiple `WWW-Authenticate` headers
* Fri Jun 17 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.1
  * Removed obsolete parser instance to allow pickling of Osc instances
* Thu Jun  9 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.6.0
  * Support for the "Signature authentication scheme"
  * Revised method to retrieve credentials from `osc`
* Tue May 17 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.5.0
  * Added capability to log API requests (without headers!) and responses
  * Make it possible to add a comment when pushing files
  * Added method to get build history
* Thu Jan 20 2022 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.4.2
  * Bugfix: Explicitly quote special characters in URLs
* Wed Sep 22 2021 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.4.1
  * Bugfix for configuration utilities
- Release 0.4.0
  * Added support to parse `osc` configuration
  * Bugfix for `origin` extension
* Wed Feb 24 2021 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.3.3
  * Added the `expand` parameter to some methods of the packages extension.
* Thu Jan  7 2021 Andreas Hasenkopf <ahasenkopf@suse.com>
- Release 0.3.2
  * Support cached_property decorator from the OpenSUSE package
- Release 0.3.1
  * Support for PyYAML without libyaml
- Release 0.3.0
  * Added osctiny.extensions.origin
  * Added osctiny.utils.mapping
  * Removed support for all Python version prior to 3.6
* Tue Sep 15 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- version update to 0.2.4
  * Added osctiny.extensions.buildresults.Build.get_binary()
  * Added osctiny.extensions.buildresults.Build.get_package_list()
  * Changed osctiny.osc.Osc.get_objectified_xml() to accept request objects and strings
* Mon Jun 29 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- version update to 0.2.3
  * Added the `distributions` extension
* Tue Jun  2 2020 pgajdos@suse.com
- for python2, require python2-unittest2 and python2-mock for build
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 0.2.2
  * Added the `issues` extension
  * Give (read only) access to issues and issue trackers known to BuildService
  * Set version to 0.2.2
  * Dirty hacks for Python2 compatibility
* Thu Jan  9 2020 Chen Huang <chhuang@suse.com>
- Updated to version 0.2.1
- Allow invalid timestamps during changelog parsing
- Removed dependency of the future package
- Backport for Python2 compatibility
- Bugfixes for :py:mod:`osctiny.utils.changelog`
* Mon Dec 30 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- Version 0.1.11
- Changed structure of sub-modules
- Added `osctiny.utils.changelog`
- Added parameter `expand` to `osctiny.extensions.packages.Package.get_file`
* Tue Dec  3 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- Source package instead of _serive "download_files"
* Tue Dec  3 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- Version 0.1.10
* Tue Dec  3 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- New package osc-tiny (version 0.1.9)
